/*
 *  linux/arch/mips/kernel/proc.c
 *
 *  Copyright (C) 1995, 1996  Ralf Baechle
 */
#include <linux/delay.h>
#include <linux/kernel.h>
#include <asm/bootinfo.h>
#include <asm/mipsregs.h>

unsigned long dflushes = 0;
unsigned long iflushes = 0;

/*
 * BUFFER is PAGE_SIZE bytes long.
 *
 * Currently /proc/cpuinfo is being abused to print data about the
 * number of date/instruction cacheflushes.
 */
int get_cpuinfo(char *buffer)
{
	const char *cpu_name[] = CPU_NAMES;
	const char *mach_group_names[] = GROUP_NAMES;
	const char *mach_unknown_names[] = GROUP_UNKNOWN_NAMES;
	const char *mach_jazz_names[] = GROUP_JAZZ_NAMES;
	const char *mach_dec_names[] = GROUP_DEC_NAMES;
	const char *mach_arc_names[] = GROUP_ARC_NAMES;
	const char *mach_sni_rm_names[] = GROUP_SNI_RM_NAMES;
	const char **mach_group_to_name[] = { mach_unknown_names, mach_jazz_names,
					    mach_dec_names, mach_arc_names, mach_sni_rm_names};
	unsigned int version = read_32bit_cp0_register(CP0_PRID);

	return sprintf(buffer,
		       "cpu\t\t\t: MIPS\n"
		       "cpu model\t\t: %s V%d.%d\n"
		       "system type\t\t: %s %s\n"
		       "BogoMIPS\t\t: %lu.%02lu\n"
#if defined (__MIPSEB__)
	               "byteorder\t\t: big endian\n"
#elif defined (__MIPSEL__)
	               "byteorder\t\t: little endian\n"
#else
#error "Wiered endian???"
#endif
	               /*
	                * This is just profiling stuff that will go away.
	                */
		       "D-cacheflushes\t\t: %lu\n"
		       "I-cacheflushes\t\t: %lu\n",

		       cpu_name[mips_cputype <= CPU_LAST ? mips_cputype : CPU_UNKNOWN], (version >> 4) & 0x0f, version & 0x0f,
		       mach_group_names[mips_machgroup],
		       mach_group_to_name[mips_machgroup][mips_machtype],
		       (loops_per_sec + 2500) / 500000,
	               ((loops_per_sec + 2500) / 5000) % 100,
		       dflushes,iflushes
		       );
}
